@@ -11,7 +11,11 @@ if (!isGeneric("getValues")) {
 setMethod("getValues", signature(x='RasterLayer', row='missing', nrows='missing'), 
 function(x, format='') {
 	
-	xx = c(x@ncols, x@nrows)
+	xx <- c(x@ncols, x@nrows)
+	f <- is.factor(x)
+	if (f) {
+		labs <- labels(x)
+	}
 	
 	if ( inMemory(x) ) {
 		x <- x@data@values
@@ -20,11 +24,14 @@ function(x, format='') {
 	} else {
 		x <- rep(NA, ncell(x))
 	}
-	
+
 	if (format=='matrix') { 
 		x <- matrix(x, ncol=xx[1], nrow=xx[2], byrow=TRUE) 
-	} 
-	
+	} else if (f) {
+		x <- factor(x)
+		# set labels?
+	}	
+
 	return( x ) 
 }
 )
