@@ -9,8 +9,8 @@ if (!isGeneric("persp")) {
 }	
 
 setMethod("persp", signature(x='RasterLayer'), 
-	function(x, maxpixels=100000, extent=NULL, ...)  {
-		x <- sampleRegular(x, size=maxpixels, extent=extent, asRaster=TRUE, corners=TRUE)
+	function(x, maxpixels=100000, ext=NULL, ...)  {
+		x <- sampleRegular(x, size=maxpixels, ext=ext, asRaster=TRUE)
 		value <- t((getValues(x, format='matrix'))[nrow(x):1,])
 		y <- yFromRow(x, nrow(x):1)
 		x <- xFromCol(x,1:ncol(x))
@@ -19,11 +19,11 @@ setMethod("persp", signature(x='RasterLayer'),
 )
 
 setMethod("persp", signature(x='RasterStackBrick'), 
-	function(x, y=1, maxpixels=10000, extent=NULL, ...)  {
+	function(x, y=1, maxpixels=10000, ext=NULL, ...)  {
 		if (y < 1) { y <- 1 }
 		if (y > nlayers(x)) { y <- nlayers(x) }
 		x <- raster(x, y)
-		persp(x=x, maxpixels=maxpixels, extent=extent, ...)
+		persp(x=x, maxpixels=maxpixels, ext=ext, ...)
 	}	
 )
 
