@@ -12,7 +12,7 @@ if (!isGeneric("plotRGB")) {
 
 
 setMethod("plotRGB", signature(x='RasterStackBrick'), 
-function(x, r=1, g=2, b=3, scale,  maxpixels=500000, stretch=NULL, ext=NULL, interpolate=FALSE, axes=TRUE, xlab='', ylab='', asp, alpha, ...) { 
+function(x, r=1, g=2, b=3, scale,  maxpixels=500000, stretch=NULL, ext=NULL, interpolate=FALSE, axes=TRUE, xlab='', ylab='', asp, alpha, add=FALSE, addfun=NULL, ...) { 
 	
 	if (!axes) par(plt=c(0,1,0,1))
 
@@ -71,19 +71,27 @@ function(x, r=1, g=2, b=3, scale,  maxpixels=500000, stretch=NULL, ext=NULL, int
 	require(grDevices)
 	bb <- as.vector(t(bbox(r)))
 
-	plot(NA, NA, xlim=c(bb[1], bb[2]), ylim=c(bb[3], bb[4]), type = "n", xaxs='i', yaxs='i', xlab=xlab, ylab=ylab, asp=asp, axes=FALSE, ...)
+	if (!add) {
+		plot(NA, NA, xlim=c(bb[1], bb[2]), ylim=c(bb[3], bb[4]), type = "n", xaxs='i', yaxs='i', xlab=xlab, ylab=ylab, asp=asp, axes=FALSE, ...)
+		if (axes) {
+			xticks <- axTicks(1, c(xmin(r), xmax(r), 4))
+			yticks <- axTicks(2, c(ymin(r), ymax(r), 4))
+			if (xres(r) %% 1 == 0) xticks = round(xticks)
+			if (yres(r) %% 1 == 0) yticks = round(yticks)
+			axis(1, at=xticks)
+			axis(2, at=yticks, las = 1)
+			#axis(3, at=xticks, labels=FALSE, lwd.ticks=0)
+			#axis(4, at=yticks, labels=FALSE, lwd.ticks=0)
+		}
+	}
 	rasterImage(z, bb[1], bb[3], bb[2], bb[4], interpolate=interpolate, ...)
 	
-	if (axes) {
-		xticks <- axTicks(1, c(xmin(r), xmax(r), 4))
-		yticks <- axTicks(2, c(ymin(r), ymax(r), 4))
-		if (xres(r) %% 1 == 0) xticks = round(xticks)
-		if (yres(r) %% 1 == 0) yticks = round(yticks)
-		axis(1, at=xticks)
-		axis(2, at=yticks, las = 1)
-		#axis(3, at=xticks, labels=FALSE, lwd.ticks=0)
-		#axis(4, at=yticks, labels=FALSE, lwd.ticks=0)
-	}	
+	
+	if (!is.null(addfun)) {
+		if (is.function(addfun)) {
+			addfun()
+		}
+	}
 }
 )
 
