@@ -11,8 +11,16 @@ if (!isGeneric("spplot")) {
 
 
 setMethod("spplot", signature(obj='Raster'), 
-	function(obj, ..., maxpixels=50000, as.table=TRUE)  {
+	function(obj, ..., maxpixels=50000, as.table=TRUE, zlim)  {
 		obj <- sampleRegular(obj, maxpixels, asRaster=T)
+		if (!missing(zlim)) {
+			if (length(zlim) != 2) {
+				warning('zlim should be a vector of two elements')
+			} 
+			if (length(zlim) >= 2) {
+				obj[obj < zlim[1] | obj > zlim[2]] <- NA
+			}
+		}
 		obj <- as(obj, 'SpatialGridDataFrame')
 		#obj@data <- obj@data[, ncol(obj@data):1]
 		spplot(obj, ..., as.table=as.table)
